@@ -1,5 +1,5 @@
 <?php
-// $Horde: nag/lib/Driver.php,v 1.22.2.6 2002/12/17 03:48:19 jon Exp $
+// $Horde: nag/lib/Driver.php,v 1.22.2.7 2004/09/14 18:38:13 chuck Exp $
 
 // Internal status flags (for bitwise operations)
 /** @constant TASK_ANY Task has any flag set. */
@@ -18,7 +18,7 @@ define('TASK_DELETED', 4);
  * Nag_Driver:: defines an API for implementing storage backends for Nag.
  *
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.22.2.6 $
+ * @version $Revision: 1.22.2.7 $
  * @since   Nag 0.1
  * @package nag
  */
@@ -174,7 +174,7 @@ class Nag_Driver {
      */
     function modifyTask($id, $attribute, $value)
     {
-        if (isset($this->_tasks[$id]) && isset($this->_tasks[$id][strtolower($attribute)])) {
+        if (isset($this->_tasks[$id]) && array_key_exists(strtolower($attribute), $this->_tasks[$id])) {
             $this->_tasks[$id][strtolower($attribute)] = $value;
             $this->_tasks[$id]['flags'] |= TASK_MODIFIED;
             return ($this->_tasks[$id]['flags'] & TASK_MODIFIED);
